@@ -37,7 +37,7 @@ sub test_js_plugins : Tests {
     my $self = shift;
 
     return unless $self->require_executable('node');
-    return unless $self->require_executable('js-beautify');
+    return unless $self->require_executable('js-beautify') || $ENV{TRAVIS};
     return unless $self->require_executable('jshint');
     return unless $self->require_executable('jslint');
 
@@ -46,9 +46,9 @@ sub test_js_plugins : Tests {
 
     $self->tidyall(
         plugin_conf => {
-            JSBeautify => { select => '**/*.js' },
-            JSHint     => { select => '**/*.js' },
-            JSLint     => { select => '**/*.js' },
+            ( $ENV{TRAVIS} ? () : ( JSBeautify => { select => '**/*.js' } ) ),
+            JSHint => { select => '**/*.js' },
+            JSLint => { select => '**/*.js' },
         },
         source_file => $file,
         expect_ok   => 1,
